Gallery
=======

The gallery is a preview of the different plot types available in ``sumo``. Click on any
image to see the command to produce a similar plot.

sumo-dosplot
~~~~~~~~~~~~~

.. image:: figures/dos_square.png
   :height: 250px
   :target: sumo-dosplot.html#basic-options

.. image:: figures/dos_subplot.png
   :height: 250px
   :target: sumo-dosplot.html#subplots


sumo-bandplot
~~~~~~~~~~~~~~

.. image:: figures/band_basic.png
   :height: 250px
   :target: sumo-bandplot.html#usage

.. image:: figures/band_with_dos.png
   :height: 250px
   :target: sumo-bandplot.html#combined-band-structure-and-density-of-states-plots

.. image:: figures/band_projected_rgb.png
   :height: 250px
   :target: sumo-bandplot.html#projected-band-structures

.. image:: figures/band_projected_stacked.png
   :height: 250px
   :target: sumo-bandplot.html#projected-band-structures

.. image:: figures/band_projected_advanced.png
   :height: 250px
   :target: sumo-bandplot.html#advanced-example

sumo-optplot
~~~~~~~~~~~~~

.. image:: figures/absorption_basic.png
   :height: 250px
   :target: sumo-optplot.html#usage

.. image:: figures/absorption_anisotropic.png
   :height: 250px
   :target: sumo-optplot.html#anisotropic-absorption

.. image:: figures/absorption_bandgap.png
   :height: 250px
   :target: sumo-optplot.html#displaying-band-gaps

.. image:: figures/absorption_multi.png
   :height: 250px
   :target: sumo-optplot.html#plotting-multiple-spectra


sumo-phonon-bandplot
~~~~~~~~~~~~~~~~~~~~~

.. image:: figures/phonon_band_basic.png
   :height: 250px
   :target: sumo-phonon-bandplot.html#usage
